@@ -1,6 +1,11 @@
 use serde::{Deserialize, Serialize};
 use std::collections::HashMap;
-use crate::{indexes::Index, errors::Error, request::{request, Method}, progress::{Progress, ProgressJson}};
+use crate::{
+    indexes::Index,
+    errors::Error,
+    request::{request, Method},
+    progress::{Progress, ProgressJson}
+};
 
 /// Struct reprensenting a set of settings.
 /// You can build this struct using the builder syntax.
@@ -213,7 +218,7 @@ impl Settings {
     }
 }
 
-impl<'a> Index<'a> {
+impl Index {
     /// Get [settings](../settings/struct.Settings.html) of the Index.
     ///
     /// ```
@@ -226,8 +231,8 @@ impl<'a> Index<'a> {
     /// ```
     pub async fn get_settings(&self) -> Result<Settings, Error> {
         Ok(request::<(), Settings>(
-            &format!("{}/indexes/{}/settings", self.client.host, self.uid),
-            self.client.apikey,
+            &format!("{}/indexes/{}/settings", self.host, self.uid),
+            &self.api_key,
             Method::Get,
             200,
         ).await?)
@@ -245,8 +250,8 @@ impl<'a> Index<'a> {
     /// ```
     pub async fn get_synonyms(&self) -> Result<HashMap<String, Vec<String>>, Error> {
         Ok(request::<(), HashMap<String, Vec<String>>>(
-            &format!("{}/indexes/{}/settings/synonyms", self.client.host, self.uid),
-            self.client.apikey,
+            &format!("{}/indexes/{}/settings/synonyms", self.host, self.uid),
+            &self.api_key,
             Method::Get,
             200,
         ).await?)
@@ -264,8 +269,8 @@ impl<'a> Index<'a> {
     /// ```
     pub async fn get_stop_words(&self) -> Result<Vec<String>, Error> {
         Ok(request::<(), Vec<String>>(
-            &format!("{}/indexes/{}/settings/stop-words", self.client.host, self.uid),
-            self.client.apikey,
+            &format!("{}/indexes/{}/settings/stop-words", self.host, self.uid),
+            &self.api_key,
             Method::Get,
             200,
         ).await?)
@@ -283,8 +288,8 @@ impl<'a> Index<'a> {
     /// ```
     pub async fn get_ranking_rules(&self) -> Result<Vec<String>, Error> {
         Ok(request::<(), Vec<String>>(
-            &format!("{}/indexes/{}/settings/ranking-rules", self.client.host, self.uid),
-            self.client.apikey,
+            &format!("{}/indexes/{}/settings/ranking-rules", self.host, self.uid),
+            &self.api_key,
             Method::Get,
             200,
         ).await?)
@@ -302,8 +307,8 @@ impl<'a> Index<'a> {
     /// ```
     pub async fn get_attributes_for_faceting(&self) -> Result<Vec<String>, Error> {
         Ok(request::<(), Vec<String>>(
-            &format!("{}/indexes/{}/settings/attributes-for-faceting", self.client.host, self.uid),
-            self.client.apikey,
+            &format!("{}/indexes/{}/settings/attributes-for-faceting", self.host, self.uid),
+            &self.api_key,
             Method::Get,
             200,
         ).await?)
@@ -321,8 +326,8 @@ impl<'a> Index<'a> {
     /// ```
     pub async fn get_distinct_attribute(&self) -> Result<Option<String>, Error> {
         Ok(request::<(), Option<String>>(
-            &format!("{}/indexes/{}/settings/distinct-attribute", self.client.host, self.uid),
-            self.client.apikey,
+            &format!("{}/indexes/{}/settings/distinct-attribute", self.host, self.uid),
+            &self.api_key,
             Method::Get,
             200,
         ).await?)
@@ -340,8 +345,8 @@ impl<'a> Index<'a> {
     /// ```
     pub async fn get_searchable_attributes(&self) -> Result<Vec<String>, Error> {
         Ok(request::<(), Vec<String>>(
-            &format!("{}/indexes/{}/settings/searchable-attributes", self.client.host, self.uid),
-            self.client.apikey,
+            &format!("{}/indexes/{}/settings/searchable-attributes", self.host, self.uid),
+            &self.api_key,
             Method::Get,
             200,
         ).await?)
@@ -359,8 +364,8 @@ impl<'a> Index<'a> {
     /// ```
     pub async fn get_displayed_attributes(&self) -> Result<Vec<String>, Error> {
         Ok(request::<(), Vec<String>>(
-            &format!("{}/indexes/{}/settings/displayed-attributes", self.client.host, self.uid),
-            self.client.apikey,
+            &format!("{}/indexes/{}/settings/displayed-attributes", self.host, self.uid),
+            &self.api_key,
             Method::Get,
             200,
         ).await?)
@@ -386,10 +391,10 @@ impl<'a> Index<'a> {
     /// # progress.get_status().await.unwrap();
     /// # });
     /// ```
-    pub async fn set_settings(&'a self, settings: &Settings) -> Result<Progress<'a>, Error> {
+    pub async fn set_settings(&self, settings: &Settings) -> Result<Progress, Error> {
         Ok(request::<&Settings, ProgressJson>(
-            &format!("{}/indexes/{}/settings", self.client.host, self.uid),
-            self.client.apikey,
+            &format!("{}/indexes/{}/settings", self.host, self.uid),
+            &self.api_key,
             Method::Post(settings),
             202,
         ).await?
@@ -416,10 +421,10 @@ impl<'a> Index<'a> {
     /// # progress.get_status().await.unwrap();
     /// # });
     /// ```
-    pub async fn set_synonyms(&'a self, synonyms: &HashMap<String, Vec<String>>) -> Result<Progress<'a>, Error> {
+    pub async fn set_synonyms(&self, synonyms: &HashMap<String, Vec<String>>) -> Result<Progress, Error> {
         Ok(request::<&HashMap<String, Vec<String>>, ProgressJson>(
-            &format!("{}/indexes/{}/settings/synonyms", self.client.host, self.uid),
-            self.client.apikey,
+            &format!("{}/indexes/{}/settings/synonyms", self.host, self.uid),
+            &self.api_key,
             Method::Post(synonyms),
             202,
         ).await?
@@ -442,10 +447,10 @@ impl<'a> Index<'a> {
     /// # progress.get_status().await.unwrap();
     /// # });
     /// ```
-    pub async fn set_stop_words(&'a self, stop_words: impl IntoVecString) -> Result<Progress<'a>, Error> {
+    pub async fn set_stop_words(&self, stop_words: impl IntoVecString) -> Result<Progress, Error> {
         Ok(request::<Vec<String>, ProgressJson>(
-            &format!("{}/indexes/{}/settings/stop-words", self.client.host, self.uid),
-            self.client.apikey,
+            &format!("{}/indexes/{}/settings/stop-words", self.host, self.uid),
+            &self.api_key,
             Method::Post(stop_words.convert()),
             202,
         ).await?
@@ -477,10 +482,10 @@ impl<'a> Index<'a> {
     /// # progress.get_status().await.unwrap();
     /// # });
     /// ```
-    pub async fn set_ranking_rules(&'a self, ranking_rules: impl IntoVecString) -> Result<Progress<'a>, Error> {
+    pub async fn set_ranking_rules(&self, ranking_rules: impl IntoVecString) -> Result<Progress, Error> {
         Ok(request::<Vec<String>, ProgressJson>(
-            &format!("{}/indexes/{}/settings/ranking-rules", self.client.host, self.uid),
-            self.client.apikey,
+            &format!("{}/indexes/{}/settings/ranking-rules", self.host, self.uid),
+            &self.api_key,
             Method::Post(ranking_rules.convert()),
             202,
         ).await?
@@ -503,10 +508,10 @@ impl<'a> Index<'a> {
     /// # progress.get_status().await.unwrap();
     /// # });
     /// ```
-    pub async fn set_attributes_for_faceting(&'a self, attributes_for_faceting: impl IntoVecString) -> Result<Progress<'a>, Error> {
+    pub async fn set_attributes_for_faceting(&self, attributes_for_faceting: impl IntoVecString) -> Result<Progress, Error> {
         Ok(request::<Vec<String>, ProgressJson>(
-            &format!("{}/indexes/{}/settings/attributes-for-faceting", self.client.host, self.uid),
-            self.client.apikey,
+            &format!("{}/indexes/{}/settings/attributes-for-faceting", self.host, self.uid),
+            &self.api_key,
             Method::Post(attributes_for_faceting.convert()),
             202,
         ).await?
@@ -528,10 +533,10 @@ impl<'a> Index<'a> {
     /// # progress.get_status().await.unwrap();
     /// # });
     /// ```
-    pub async fn set_distinct_attribute(&'a self, distinct_attribute: impl Into<String>) -> Result<Progress<'a>, Error> {
+    pub async fn set_distinct_attribute(&self, distinct_attribute: impl Into<String>) -> Result<Progress, Error> {
         Ok(request::<String, ProgressJson>(
-            &format!("{}/indexes/{}/settings/distinct-attribute", self.client.host, self.uid),
-            self.client.apikey,
+            &format!("{}/indexes/{}/settings/distinct-attribute", self.host, self.uid),
+            &self.api_key,
             Method::Post(distinct_attribute.into()),
             202,
         ).await?
@@ -553,10 +558,10 @@ impl<'a> Index<'a> {
     /// # progress.get_status().await.unwrap();
     /// # });
     /// ```
-    pub async fn set_searchable_attributes(&'a self, searchable_attributes: impl IntoVecString) -> Result<Progress<'a>, Error> {
+    pub async fn set_searchable_attributes(&self, searchable_attributes: impl IntoVecString) -> Result<Progress, Error> {
         Ok(request::<Vec<String>, ProgressJson>(
-            &format!("{}/indexes/{}/settings/searchable-attributes", self.client.host, self.uid),
-            self.client.apikey,
+            &format!("{}/indexes/{}/settings/searchable-attributes", self.host, self.uid),
+            &self.api_key,
             Method::Post(searchable_attributes.convert()),
             202,
         ).await?
@@ -578,10 +583,10 @@ impl<'a> Index<'a> {
     /// # progress.get_status().await.unwrap();
     /// # });
     /// ```
-    pub async fn set_displayed_attributes(&'a self, displayed_attributes: impl IntoVecString) -> Result<Progress<'a>, Error> {
+    pub async fn set_displayed_attributes(&self, displayed_attributes: impl IntoVecString) -> Result<Progress, Error> {
         Ok(request::<Vec<String>, ProgressJson>(
-            &format!("{}/indexes/{}/settings/displayed-attributes", self.client.host, self.uid),
-            self.client.apikey,
+            &format!("{}/indexes/{}/settings/displayed-attributes", self.host, self.uid),
+            &self.api_key,
             Method::Post(displayed_attributes.convert()),
             202,
         ).await?
@@ -604,10 +609,10 @@ impl<'a> Index<'a> {
     /// # progress.get_status().await.unwrap();
     /// # });
     /// ```
-    pub async fn reset_settings(&'a self) -> Result<Progress<'a>, Error> {
+    pub async fn reset_settings(&self) -> Result<Progress, Error> {
         Ok(request::<(), ProgressJson>(
-            &format!("{}/indexes/{}/settings", self.client.host, self.uid),
-            self.client.apikey,
+            &format!("{}/indexes/{}/settings", self.host, self.uid),
+            &self.api_key,
             Method::Delete,
             202,
         ).await?
@@ -629,10 +634,10 @@ impl<'a> Index<'a> {
     /// # progress.get_status().await.unwrap();
     /// # });
     /// ```
-    pub async fn reset_synonyms(&'a self) -> Result<Progress<'a>, Error> {
+    pub async fn reset_synonyms(&self) -> Result<Progress, Error> {
         Ok(request::<(), ProgressJson>(
-            &format!("{}/indexes/{}/settings/synonyms", self.client.host, self.uid),
-            self.client.apikey,
+            &format!("{}/indexes/{}/settings/synonyms", self.host, self.uid),
+            &self.api_key,
             Method::Delete,
             202,
         ).await?
@@ -654,10 +659,10 @@ impl<'a> Index<'a> {
     /// # progress.get_status().await.unwrap();
     /// # });
     /// ```
-    pub async fn reset_stop_words(&'a self) -> Result<Progress<'a>, Error> {
+    pub async fn reset_stop_words(&self) -> Result<Progress, Error> {
         Ok(request::<(), ProgressJson>(
-            &format!("{}/indexes/{}/settings/stop-words", self.client.host, self.uid),
-            self.client.apikey,
+            &format!("{}/indexes/{}/settings/stop-words", self.host, self.uid),
+            &self.api_key,
             Method::Delete,
             202,
         ).await?
@@ -680,10 +685,10 @@ impl<'a> Index<'a> {
     /// # progress.get_status().await.unwrap();
     /// # });
     /// ```
-    pub async fn reset_ranking_rules(&'a self) -> Result<Progress<'a>, Error> {
+    pub async fn reset_ranking_rules(&self) -> Result<Progress, Error> {
         Ok(request::<(), ProgressJson>(
-            &format!("{}/indexes/{}/settings/ranking-rules", self.client.host, self.uid),
-            self.client.apikey,
+            &format!("{}/indexes/{}/settings/ranking-rules", self.host, self.uid),
+            &self.api_key,
             Method::Delete,
             202,
         ).await?
@@ -705,10 +710,10 @@ impl<'a> Index<'a> {
     /// # progress.get_status().await.unwrap();
     /// # });
     /// ```
-    pub async fn reset_attributes_for_faceting(&'a self) -> Result<Progress<'a>, Error> {
+    pub async fn reset_attributes_for_faceting(&self) -> Result<Progress, Error> {
         Ok(request::<(), ProgressJson>(
-            &format!("{}/indexes/{}/settings/attributes-for-faceting", self.client.host, self.uid),
-            self.client.apikey,
+            &format!("{}/indexes/{}/settings/attributes-for-faceting", self.host, self.uid),
+            &self.api_key,
             Method::Delete,
             202,
         ).await?
@@ -730,10 +735,10 @@ impl<'a> Index<'a> {
     /// # progress.get_status().await.unwrap();
     /// # });
     /// ```
-    pub async fn reset_distinct_attribute(&'a self) -> Result<Progress<'a>, Error> {
+    pub async fn reset_distinct_attribute(&self) -> Result<Progress, Error> {
         Ok(request::<(), ProgressJson>(
-            &format!("{}/indexes/{}/settings/distinct-attribute", self.client.host, self.uid),
-            self.client.apikey,
+            &format!("{}/indexes/{}/settings/distinct-attribute", self.host, self.uid),
+            &self.api_key,
             Method::Delete,
             202,
         ).await?
@@ -755,10 +760,10 @@ impl<'a> Index<'a> {
     /// # progress.get_status().await.unwrap();
     /// # });
     /// ```
-    pub async fn reset_searchable_attributes(&'a self) -> Result<Progress<'a>, Error> {
+    pub async fn reset_searchable_attributes(&self) -> Result<Progress, Error> {
         Ok(request::<(), ProgressJson>(
-            &format!("{}/indexes/{}/settings/searchable-attributes", self.client.host, self.uid),
-            self.client.apikey,
+            &format!("{}/indexes/{}/settings/searchable-attributes", self.host, self.uid),
+            &self.api_key,
             Method::Delete,
             202,
         ).await?
@@ -780,10 +785,10 @@ impl<'a> Index<'a> {
     /// # progress.get_status().await.unwrap();
     /// # });
     /// ```
-    pub async fn reset_displayed_attributes(&'a self) -> Result<Progress<'a>, Error> {
+    pub async fn reset_displayed_attributes(&self) -> Result<Progress, Error> {
         Ok(request::<(), ProgressJson>(
-            &format!("{}/indexes/{}/settings/displayed-attributes", self.client.host, self.uid),
-            self.client.apikey,
+            &format!("{}/indexes/{}/settings/displayed-attributes", self.host, self.uid),
+            &self.api_key,
             Method::Delete,
             202,
         ).await?
